# Changelog

## 0.1.8

- Trim keywords to match pyproject template guide

## 0.1.2

- Add Development section to README

## 0.1.0 (2026-03-10)

- Initial release
- ASGI middleware for FastAPI/Starlette
- WSGI middleware for Flask/Django
- Slow request threshold warnings
- Server-Timing response header
